@@ -137,7 +137,7 @@ public:
   void Undo();
 
 private:
-  UpdateGUICommand& operator=(const UpdateGUICommand&); // Do not implement
+  UpdateGUICommand& operator=(const UpdateGUICommand&) = delete; // Do not implement
   UpdateGUICommand(CommandInterface *pcomInt, ExecuteFn When,
                    GUI_Action ga, const pws_os::CUUID &entryUUID);
   const ExecuteFn m_When;
@@ -241,13 +241,12 @@ public:
   friend class DeleteEntryCommand; // allow access to c'tor
 
 private:
-  AddEntryCommand& operator=(const AddEntryCommand&); // Do not implement
+  AddEntryCommand& operator=(const AddEntryCommand&) = delete; // Do not implement
   AddEntryCommand(CommandInterface *pcomInt, const CItemData &ci,
                   const pws_os::CUUID &baseUUID, const CItemAtt *att,
                   const Command *pcmd = nullptr);
   CItemData m_ci;
   CItemAtt m_att;
-  bool m_bExpired;
 };
 
 class DeleteEntryCommand : public Command
@@ -264,7 +263,7 @@ public:
   friend class AddEntryCommand; // allow access to c'tor
 
 private:
-  DeleteEntryCommand& operator=(const DeleteEntryCommand&); // Do not implement
+  DeleteEntryCommand& operator=(const DeleteEntryCommand&) = delete; // Do not implement
   DeleteEntryCommand(CommandInterface *pcomInt, const CItemData &ci,
                      const Command *pcmd = nullptr);
   const CItemData m_ci;
@@ -291,6 +290,43 @@ private:
   CItemData m_new_ci;
 };
 
+class DeleteAttachmentCommand : public Command
+{
+public:
+  static DeleteAttachmentCommand *Create(CommandInterface *pcomInt,
+    const CItemData &ci,
+    const Command *pcmd = nullptr)
+  { return new DeleteAttachmentCommand(pcomInt, ci, pcmd); }
+  ~DeleteAttachmentCommand();
+  int Execute();
+  void Undo();
+
+private:
+  DeleteAttachmentCommand& operator=(const DeleteEntryCommand&) = delete; // Do not implement
+  DeleteAttachmentCommand(CommandInterface *pcomInt, const CItemData &ci,
+    const Command *pcmd = nullptr);
+  const CItemData m_ci;
+  CItemAtt m_att;
+};
+
+class EditAttachmentCommand : public Command
+{
+public:
+  static EditAttachmentCommand *Create(CommandInterface *pcomInt,
+    const CItemAtt &old_att,
+    const CItemAtt &new_att)
+  { return new EditAttachmentCommand(pcomInt, old_att, new_att); }
+  ~EditAttachmentCommand();
+  int Execute();
+  void Undo();
+
+private:
+  EditAttachmentCommand(CommandInterface *pcomInt, const CItemAtt &old_att,
+    const CItemAtt &new_att);
+  CItemAtt m_old_att;
+  CItemAtt m_new_att;
+};
+
 class UpdateEntryCommand : public Command
 {
 public:
