@@ -89,7 +89,8 @@ public:
     DB_HAS_DUPLICATES,                        //  21
     OK_WITH_ERRORS,                           //  22
     OK_WITH_VALIDATION_ERRORS,                //  23
-    OPEN_NODB                                 //  24
+    OPEN_NODB,                                //  24
+    MAX_SIZE_EXCEEDED                         //  25
   };
 
   PWScore();
@@ -155,7 +156,7 @@ public:
 
   // R/O file status
   void SetReadOnly(bool state) {m_bIsReadOnly = state;}
-  bool IsReadOnly() const {return m_bIsReadOnly;};
+  bool IsReadOnly() const {return m_bIsReadOnly;}
 
   // Check/Change master passphrase
   int CheckPasskey(const StringX &filename, const StringX &passkey);
@@ -459,6 +460,9 @@ private:
   virtual void DoAddEntry(const CItemData &item, const CItemAtt *att);
   virtual void DoDeleteEntry(const CItemData &item);
   virtual void DoReplaceEntry(const CItemData &old_ci, const CItemData &new_ci);
+  virtual void DoAddAttachment(const CItemAtt &att);
+  virtual void DoDeleteAttachment(const CItemAtt &att);
+  virtual void DoReplaceAttachment(const CItemAtt &old_att, const CItemAtt &new_att);
 
   // General routines for aliases and shortcuts
   virtual void DoAddDependentEntry(const pws_os::CUUID &base_uuid,
