@@ -287,6 +287,7 @@
 #define IDSC_IMPORTEDEMPTYGROUPS        3459
 #define IDSC_FILTERSEXPORTEDTODB        3460
 #define IDSC_FOUNDENTRIESFILTER         3461
+#define IDSC_IMPORTINVALIDDELIMITER     3462
 
 // Keep DCA together
 #define IDSC_CURRENTDEFAULTDCA          4000
@@ -331,3 +332,5 @@
 #define IDSC_PHEXADECIMAL               4113
 #define IDSC_DEFAULT_POLICY             4114
 #define IDSC_ATLEASTIGNORED             4115
+
+#define IDSC_INVALIDLOCKER              4116
