@@ -13,14 +13,9 @@
 // For compilers that support precompilation, includes "wx/wx.h".
 #include <wx/wxprec.h>
 
-#ifdef __BORLANDC__
-#pragma hdrstop
-#endif
-
 #ifndef WX_PRECOMP
 #include <wx/wx.h>
 #endif
-#include <wx/url.h>
 
 ////@begin includes
 ////@end includes
@@ -60,8 +55,8 @@ END_EVENT_TABLE()
 
 wxString AboutDlg::s_VersionData = wxEmptyString;
 
-const wstringT s_URL_HOME      = L"https://pwsafe.org";
-const cstringT s_URL_VERSION   =  "https://pwsafe.org/latest.xml";
+const wstringT AboutDlg::s_URL_HOME      = L"https://pwsafe.org";
+const cstringT AboutDlg::s_URL_VERSION   =  "https://pwsafe.org/latest.xml";
 
 /*!
  * AboutDlg constructors
@@ -601,7 +596,7 @@ void AboutDlg::CompareVersionData()
  * This function gets executed in the secondary thread context and will use the
  * blocking function <code>curl_easy_perform</code> to perform the download,
  * which returns when download was successful, it failed or the configured timeout
- * occured. After <code>curl_easy_perform</code> completed the worker thread sends
+ * occurred. After <code>curl_easy_perform</code> completed the worker thread sends
  * a notification event to its parent thread to inform it about the result. The
  * parent thread will decide on the received exit code how to proceed.
  *
@@ -629,7 +624,7 @@ wxThread::ExitCode AboutDlg::Entry()
     // We are done. Let's inform the parent thread about the status.
     wxQueueEvent(GetEventHandler(), event);
 
-    return (wxThread::ExitCode)curlResult;
+    return reinterpret_cast<wxThread::ExitCode>(curlResult);
   }
   else {
     // Unexpected case that thread was started while no Curl handle exists
@@ -639,10 +634,10 @@ wxThread::ExitCode AboutDlg::Entry()
     // We are done. Let's inform the parent thread about the status.
     wxQueueEvent(GetEventHandler(), event);
 
-    return (wxThread::ExitCode)-1;
+    return reinterpret_cast<wxThread::ExitCode>(-1);
   }
 #else // !HAS_CURL
-  return (wxThread::ExitCode)-1;
+  return reinterpret_cast<wxThread::ExitCode>(-1);
 #endif // HAS_CURL
 }
 
@@ -679,7 +674,7 @@ size_t AboutDlg::WriteCallback(char *receivedData, size_t size, size_t bytes, vo
  *
  * This event handler is called by worker thread when file download is accomplished.
  * CURLE_OK is the only acceptable exit code from worker thread to continue with version check.
- * All other exit codes indicate some sort of occured problem.
+ * All other exit codes indicate some sort of occurred problem.
  *
  * @see method <code>AboutDlg::Entry()</code> regarding worker thread and its exit codes.
  */
