@@ -13,35 +13,31 @@
 // For compilers that support precompilation, includes "wx/wx.h".
 #include "wx/wxprec.h"
 
-#ifdef __BORLANDC__
-#pragma hdrstop
-#endif
-
 #ifndef WX_PRECOMP
 #include "wx/wx.h"
 #endif
 
-#include "./CompareDlg.h"
-#include "./DbSelectionPanel.h"
-#include "./wxUtilities.h"
-#include "../../core/PWScore.h"
-#include "./AdvancedSelectionDlg.h"
-#include "./ComparisonGridTable.h"
-#include "./SizeRestrictedPanel.h"
-#include "../../core/core.h"
-#include "./AddEditPropSheetDlg.h"
-#include "./FieldSelectionDlg.h"
-#include "./SelectionCriteria.h"
-
-#include <wx/statline.h>
-#include <wx/grid.h>
-#include <wx/ptr_scpd.h>
-#include <wx/filename.h>
-
 #ifdef __WXMSW__
 #include <wx/msw/msvcrt.h>
 #endif
 
+#include <wx/filename.h>
+#include <wx/grid.h>
+#include <wx/ptr_scpd.h>
+#include <wx/statline.h>
+
+#include "core/core.h"
+#include "core/PWScore.h"
+
+#include "AddEditPropSheetDlg.h"
+#include "AdvancedSelectionDlg.h"
+#include "CompareDlg.h"
+#include "ComparisonGridTable.h"
+#include "DbSelectionPanel.h"
+#include "FieldSelectionDlg.h"
+#include "SelectionCriteria.h"
+#include "SizeRestrictedPanel.h"
+
 enum {ID_BTN_COMPARE = 100 };
 
 enum {
@@ -78,7 +74,7 @@ struct ComparisonData {
   CompareData data;
   wxSizerItem* sizerBelow;  //for managing the spacers in between
 
-  ComparisonData(): pane(0), grid(0), sizerBelow(0){}
+  ComparisonData(): pane(nullptr), grid(nullptr), sizerBelow(nullptr){}
   ~ComparisonData() { /*nothing to do.  All window objects deleted automatically */ }
 };
 
@@ -100,9 +96,9 @@ CompareDlg::CompareDlg(wxWindow* parent, PWScore* currentCore): wxDialog(parent,
                                                                 m_currentCore(currentCore),
                                                                 m_otherCore(new PWSAuxCore),
                                                                 m_selCriteria(new SelectionCriteria),
-                                                                m_dbPanel(0),
-                                                                m_dbSelectionPane(0),
-                                                                m_optionsPane(0),
+                                                                m_dbPanel(nullptr),
+                                                                m_dbSelectionPane(nullptr),
+                                                                m_optionsPane(nullptr),
                                                                 m_current(new ComparisonData),
                                                                 m_comparison(new ComparisonData),
                                                                 m_conflicts(new ComparisonData),
@@ -156,7 +152,8 @@ void CompareDlg::CreateControls()
 
   m_dbSelectionPane->Expand();
 
-  dlgSizer->Add(new wxStaticLine(this), wxSizerFlags().Center().Expand().Border(wxLEFT|wxRIGHT, SideMargin).Proportion(0));
+  dlgSizer->AddStretchSpacer();
+  dlgSizer->Add(new wxStaticLine(this), wxSizerFlags().Expand().Border(wxLEFT|wxRIGHT, SideMargin).Proportion(0));
   dlgSizer->AddSpacer(RowSeparation);
   auto *buttons = new wxStdDialogButtonSizer;
   buttons->Add(new wxButton(this, wxID_CANCEL));
@@ -164,7 +161,7 @@ void CompareDlg::CreateControls()
   compareButton->SetDefault();
   buttons->SetAffirmativeButton(compareButton);
   buttons->Realize();
-  dlgSizer->Add(buttons, wxSizerFlags().Center().Expand().Border(wxLEFT|wxRIGHT, SideMargin).Proportion(0));
+  dlgSizer->Add(buttons, wxSizerFlags().Expand().Border(wxLEFT|wxRIGHT, SideMargin).Proportion(0));
   dlgSizer->AddSpacer(BottomMargin);
 
   SetSizerAndFit(dlgSizer);
@@ -191,7 +188,7 @@ struct CompareDlgType {
     }
   }
 
-  static bool IsUsableField(CItemData::FieldType /*field*/) {
+  static bool IsUsableField(CItemData::FieldType WXUNUSED(field)) {
     return true;
   }
 
@@ -217,7 +214,8 @@ wxCollapsiblePane* CompareDlg::CreateDBSelectionPanel(wxSizer* dlgSizer)
                                                wxString(_("Select a PasswordSafe database to compare")),
                                                true,
                                                m_currentCore,
-                                               1);
+                                               1,
+                                               ID_BTN_COMPARE);
   dbPanelSizer->Add(m_dbPanel, wxSizerFlags().Expand().Proportion(1));
 
   dlgSizer->Add(pane, wxSizerFlags().Proportion(0).Expand().Border(wxLEFT|wxRIGHT, SideMargin/2));
@@ -259,7 +257,7 @@ wxCollapsiblePane* CompareDlg::CreateDataPanel(wxSizer* dlgSizer, const wxString
   else
     cd->grid = new wxGrid(sizedPanel, wxID_ANY, wxDefaultPosition, wxDefaultSize, 0); //don't have wxWANTS_CHARS
   //create a way to get to the ComparisonData object from the grid, which is the only thing we have in events
-  wxASSERT_MSG(cd->grid->GetClientData() == 0, wxT("wxGrid::ClientData is not nullptr on creation.  Need to use that for our purposes"));
+  wxASSERT_MSG(cd->grid->GetClientData() == nullptr, wxT("wxGrid::ClientData is not nullptr on creation.  Need to use that for our purposes"));
   cd->grid->SetClientData(cd);
 #ifndef __WXMSW__
   wxFont monospacedFont(10, wxFONTFAMILY_MODERN, wxFONTSTYLE_NORMAL, wxFONTWEIGHT_NORMAL);
@@ -312,7 +310,7 @@ void CompareDlg::OnCompare(wxCommandEvent& )
   }
 }
 
-void CompareDlg::DoCompare(wxCommandEvent& /*evt*/)
+void CompareDlg::DoCompare(wxCommandEvent& WXUNUSED(evt))
 {
   bool treatWhitespacesAsEmpty = false;
   m_currentCore->Compare(m_otherCore,
@@ -337,7 +335,7 @@ void CompareDlg::DoCompare(wxCommandEvent& /*evt*/)
                    {m_comparison, true,  false, true},
                    {m_identical,  false, false, false}
   };
-  wxSizerItem* prevSizer = 0;
+  wxSizerItem* prevSizer = nullptr;
   for(size_t idx =0; idx < WXSIZEOF(sections); ++idx) {
     ComparisonGridTable* table;
     if (sections[idx].multiSource) {
@@ -410,7 +408,7 @@ void CompareDlg::OnGridCellRightClick(wxGridEvent& evt)
   size_t selectionCount = menuContext.selectedRows.GetCount();
   if (menuContext.cdata == m_conflicts) {
     selectionCount /= 2;
-    wxCHECK_RET(menuContext.selectedItems.GetCount()%2 ==0, wxT("Conflicts grid should always select an even numer of items"));
+    wxCHECK_RET(menuContext.selectedItems.GetCount()%2 ==0, wxT("Conflicts grid should always select an even number of items"));
     //Our algorithm requires the indexes to be in order, and sometimes these are actually unsorted
     menuContext.selectedItems.Sort(pless);
     for( size_t idx = 1; idx <= selectionCount; ++idx) {
@@ -495,7 +493,7 @@ void CompareDlg::OnGridCellRightClick(wxGridEvent& evt)
   }
 
   // Make the menuContext object available to the handlers
-  EventDataInjector<wxCommandEvent> inject(&itemEditMenu, &menuContext, wxEVT_COMMAND_MENU_SELECTED);
+  EventDataInjector inject(&itemEditMenu, &menuContext, wxEVT_COMMAND_MENU_SELECTED);
 
   menuContext.cdata->grid->PopupMenu(&itemEditMenu);
 }
@@ -536,6 +534,7 @@ void CompareDlg::OnEditInCurrentDB(wxCommandEvent& evt)
 void CompareDlg::OnViewInComparisonDB(wxCommandEvent& evt)
 {
   auto *menuContext = reinterpret_cast<ContextMenuData*>(evt.GetClientData());
+  wxCHECK_RET(menuContext, wxT("Empty client data"));
   const ComparisonGridTable& table = *wxDynamicCast(menuContext->cdata->grid->GetTable(), ComparisonGridTable);
   const pws_os::CUUID& uuid = table[menuContext->selectedRows[0]].uuid1;
   wxCHECK_RET(!ViewEditEntry(m_otherCore, uuid, true), wxT("Should not need to refresh grid for just viewing entry"));
@@ -550,7 +549,7 @@ bool CompareDlg::ViewEditEntry(PWScore* core, const pws_os::CUUID& uuid, bool re
   return ae.ShowModal() == wxID_OK && !readOnly;
 }
 
-void CompareDlg::OnExpandDataPanels(wxCommandEvent& /*evt*/)
+void CompareDlg::OnExpandDataPanels(wxCommandEvent& WXUNUSED(evt))
 {
   m_dbSelectionPane->Collapse();
   m_optionsPane->Collapse();
@@ -748,7 +747,11 @@ void CompareDlg::OnSyncItemsWithCurrentDB(wxCommandEvent& evt)
                         nullptr, 0, //no fields are left unselected by default
                         nullptr, 0, //But no fields are mandatory
                         userSelection,
-                        _T("Synchronize"));
+                        _T("Synchronize"),
+                        _("Synchronize items"),
+                        _("Select fields to synchronize"),
+                        _("You must select some fields to synchronize"),
+                        _("Synchronize items"));
   if (dlg.ShowModal() == wxID_OK) {
     wxCHECK_RET(!userSelection.empty(), wxT("User did not select any fields to sync?"));
     auto *menuContext = reinterpret_cast<ContextMenuData*>(evt.GetClientData());
