@@ -13,27 +13,22 @@
 // For compilers that support precompilation, includes "wx/wx.h".
 #include "wx/wxprec.h"
 
-#ifdef __BORLANDC__
-#pragma hdrstop
-#endif
-
 #ifndef WX_PRECOMP
 #include "wx/wx.h"
 #endif
 
-#include "./ComparisonGridTable.h"
-
-#include "./AdvancedSelectionDlg.h"
-#include "./SelectionCriteria.h"
-#include "../../core/PWScore.h"
-#include "./wxUtilities.h"
-#include <algorithm>
-#include <functional>
-
 #ifdef __WXMSW__
 #include <wx/msw/msvcrt.h>
 #endif
 
+#include "core/PWScore.h"
+
+#include "AdvancedSelectionDlg.h"
+#include "ComparisonGridTable.h"
+#include "SelectionCriteria.h"
+
+#include <functional>
+
 class ComparisonGridCellAttr: public wxGridCellAttr
 {
   ComparisonGridCellAttr();
@@ -93,7 +88,7 @@ ComparisonGridTable::ComparisonGridTable(SelectionCriteria* criteria): m_criteri
 ComparisonGridTable::~ComparisonGridTable()
 {
   delete [] m_colFields;
-  m_criteria = 0;
+  m_criteria = nullptr;
 }
 
 int ComparisonGridTable::GetNumberCols()
@@ -104,7 +99,7 @@ int ComparisonGridTable::GetNumberCols()
   return m_criteria->GetNumSelectedFields() - 1; 
 }
 
-void ComparisonGridTable::SetValue(int /*row*/, int /*col*/, const wxString& /*value*/)
+void ComparisonGridTable::SetValue(int WXUNUSED(row), int WXUNUSED(col), const wxString& WXUNUSED(value))
 {
 }
 
@@ -253,7 +248,7 @@ wxString UniSafeCompareGridTable::GetValue(int row, int col)
   return retval;
 }
 
-wxGridCellAttr* UniSafeCompareGridTable::GetAttr(int /*row*/, int /*col*/, wxGridCellAttr::wxAttrKind /*kind*/)
+wxGridCellAttr* UniSafeCompareGridTable::GetAttr(int WXUNUSED(row), int WXUNUSED(col), wxGridCellAttr::wxAttrKind WXUNUSED(kind))
 {
   //wxLogDebug(wxT("UniSafeCompareGridTable::GetAttr called for %d, %d"), row, col);
   m_gridAttr->IncRef();
@@ -307,8 +302,8 @@ bool UniSafeCompareGridTable::DeleteRows(size_t pos, size_t numRows)
     //This will actually remove the item from grid display
     wxGridTableMessage msg(this,
                            wxGRIDTABLE_NOTIFY_ROWS_DELETED,
-                           reinterpret_cast<int &>(pos),
-                           reinterpret_cast<int &>(numRows));
+                           static_cast<int>(pos),
+                           static_cast<int>(numRows));
     GetView()->ProcessTableMessage(msg);
   }
 
@@ -323,7 +318,7 @@ bool UniSafeCompareGridTable::AppendRows(size_t numRows/*=1*/)
                 wxT("Items must be added to UnisafeComparisonGridTable's data before adding rows"));
     wxGridTableMessage msg(this,
                            wxGRIDTABLE_NOTIFY_ROWS_APPENDED,
-                           reinterpret_cast<int &>(numRows));
+                           static_cast<int>(numRows));
     GetView()->ProcessTableMessage(msg);
   }
   return true;
@@ -431,7 +426,7 @@ wxString MultiSafeCompareGridTable::GetValue(int row, int col)
   return retval;
 }
 
-wxGridCellAttr* MultiSafeCompareGridTable::GetAttr(int row, int col, wxGridCellAttr::wxAttrKind /*kind*/)
+wxGridCellAttr* MultiSafeCompareGridTable::GetAttr(int row, int col, wxGridCellAttr::wxAttrKind WXUNUSED(kind))
 {
   //wxLogDebug(wxT("MultiSafeCompareGridTable::GetAttr called for %d, %d"), row, col);
   wxGridCellAttr* attr = ( row%2 == 0? m_currentAttr: m_comparisonAttr );
@@ -508,8 +503,8 @@ bool MultiSafeCompareGridTable::DeleteRows(size_t pos, size_t numRows)
     //This will actually remove the item from grid display
     wxGridTableMessage msg(this,
                            wxGRIDTABLE_NOTIFY_ROWS_DELETED,
-                           reinterpret_cast<int &>(pos),
-                           reinterpret_cast<int &>(numRows));
+                           static_cast<int>(pos),
+                           static_cast<int>(numRows));
     GetView()->ProcessTableMessage(msg);
   }
 
