@@ -13,15 +13,14 @@
 * 
 */
 
-#include "CryptKeyEntryDlg.h"
 #include <wx/msgdlg.h>
 
 //(*InternalHeaders(CryptKeyEntryDlg)
 #include <wx/button.h>
-#include <wx/string.h>
-#include <wx/intl.h>
 //*)
 
+#include "CryptKeyEntryDlg.h"
+#include "wxUtilities.h"
 
 //(*IdInit(CryptKeyEntryDlg)
 //*)
@@ -84,7 +83,7 @@ CryptKeyEntryDlg::CryptKeyEntryDlg(Mode mode)
     //*)
 
     // Allow to resize the dialog only in width.
-    SetMinSize(wxSize(GetMinSize().x * 1.5, GetMinSize().y));
+    SetMinSize(wxSize(static_cast<int>(GetMinSize().x * 1.5), GetMinSize().y));
     SetMaxSize(wxSize(wxDefaultCoord, GetMinSize().y));
 
     m_Mode = mode;
@@ -120,7 +119,7 @@ void CryptKeyEntryDlg::OnOk(wxCommandEvent& WXUNUSED(event))
         return;
       }
       else {
-        m_CryptKey = std2stringx((TextCtrlKey1->GetValue()).wc_str());
+        m_CryptKey = tostringx(TextCtrlKey1->GetValue());
 
         EndModal(wxID_OK);
       }
@@ -136,7 +135,7 @@ void CryptKeyEntryDlg::OnOk(wxCommandEvent& WXUNUSED(event))
         return;
       }
       else {
-        m_CryptKey = std2stringx((TextCtrlKey1->GetValue()).wc_str());
+        m_CryptKey = tostringx(TextCtrlKey1->GetValue());
 
         EndModal(wxID_OK);
       }
