@@ -13,10 +13,6 @@
 // For compilers that support precompilation, includes "wx/wx.h".
 #include <wx/wxprec.h>
 
-#ifdef __BORLANDC__
-#pragma hdrstop
-#endif
-
 #ifndef WX_PRECOMP
 #include <wx/wx.h>
 #endif
@@ -24,15 +20,9 @@
 ////@begin includes
 ////@end includes
 
-#include <wx/memory.h>
-
 #include "GridCtrl.h"
+#include "GridTable.h"
 #include "PasswordSafeFrame.h" // for DispatchDblClickAction()
-#include "./GridTable.h"
-#include "core/Command.h"
-
-#include <algorithm>
-#include <utility> // for make_pair
 
 #ifdef __WXMSW__
 #include <wx/msw/msvcrt.h>
@@ -226,6 +216,9 @@ void GridCtrl::UpdateGUI(UpdateGUICommand::GUI_Action ga, const pws_os::CUUID &e
       // Not relevant for this view
       break;
     case UpdateGUICommand::GUI_REFRESH_ENTRY:
+      ASSERT(item != nullptr);
+      RefreshItem(*item);
+      break;
     case UpdateGUICommand::GUI_REFRESH_GROUPS:
     case UpdateGUICommand::GUI_REFRESH_BOTHVIEWS:
       // TODO: ???
@@ -391,7 +384,7 @@ void GridCtrl::Remove(const CUUID &uuid)
 
     //move all the rows up by 1
     for (size_t newRow = row + 1; newRow < m_row_map.size(); ++newRow) {
-      m_row_map[reinterpret_cast<int &>(newRow) - 1] = m_row_map[reinterpret_cast<int &>(newRow)];
+      m_row_map[static_cast<int>(newRow) - 1] = m_row_map[static_cast<int>(newRow)];
     }
 
     //remove the last row, which is now extraneous
@@ -706,10 +699,5 @@ std::tuple<int, int> GridCtrl::HitTest(const wxPoint& point) const
  */
 bool GridCtrl::HasGridCell(const std::tuple<int, int>& cellGridCoordinates) const
 {
-  if ((std::get<0>(cellGridCoordinates) < 0) && (std::get<1>(cellGridCoordinates) < 0)) {
-    return false;
-  }
-  else {
-    return true;
-  }
+  return !((std::get<0>(cellGridCoordinates) < 0) && (std::get<1>(cellGridCoordinates) < 0));
 }
