@@ -16,23 +16,19 @@
 #include <wx/wx.h>
 #endif
 
-#include "GridShortcutsValidator.h"
-
-#include "./RecentDbList.h"
-#include "./PWSafeApp.h"
-#include "../../core/PWSprefs.h"
-
-#include <wx/stockitem.h>
-
-#include <wx/grid.h>
-#include <algorithm>
-#include <functional>
-#include <iterator>
-
 #ifdef __WXMSW__
 #include <wx/msw/msvcrt.h>
 #endif
 
+#include <wx/grid.h>
+
+#include "GridShortcutsValidator.h"
+
+#include "RecentDbList.h"
+#include "PWSafeApp.h"
+
+#include <functional>
+
 static wxAcceleratorEntry nullAccel;
 
 // The in-built comparison operator also compares the menu-id, which we don't always have
@@ -291,7 +287,7 @@ void SetFont(wxGrid *grid, int row)
 
   struct FontAttr {
     wxFontWeight weight;
-    int          style;
+    wxFontStyle   style;
   } fattr[3][2] = {  // rows = {orig, custom, deleted}, cols = {shortcut, label}
     { {wxFONTWEIGHT_NORMAL, wxFONTSTYLE_NORMAL}, {wxFONTWEIGHT_NORMAL, wxFONTSTYLE_NORMAL} },
     { {wxFONTWEIGHT_BOLD,   wxFONTSTYLE_SLANT},  {wxFONTWEIGHT_BOLD,    wxFONTSTYLE_SLANT} },
@@ -331,7 +327,7 @@ void SetFont(wxGrid *grid, int row)
 /////////////////////////////////////////////////////////////////////////////////
 // PWSMenuShortcuts
 ///////////////////
-PWSMenuShortcuts::PWSMenuShortcuts(wxMenuBar* menuBar): m_shortcutsGrid(0)
+PWSMenuShortcuts::PWSMenuShortcuts(wxMenuBar* menuBar): m_shortcutsGrid(nullptr)
 {
   std::back_insert_iterator<MenuItemDataArray> inserter = std::back_inserter(m_midata);
   for( unsigned menuIndex = 0; menuIndex < menuBar->GetMenuCount(); ++menuIndex) {
@@ -343,11 +339,11 @@ PWSMenuShortcuts::~PWSMenuShortcuts()
 {
 }
 
-PWSMenuShortcuts* g_pShortcutsManager = 0;
+PWSMenuShortcuts* g_pShortcutsManager = nullptr;
 
 PWSMenuShortcuts* PWSMenuShortcuts::CreateShortcutsManager(wxMenuBar* menubar)
 {
-  wxCHECK_MSG(g_pShortcutsManager == 0, g_pShortcutsManager, wxT("Shortcuts manager being created multiple times"));
+  wxCHECK_MSG(g_pShortcutsManager == nullptr, g_pShortcutsManager, wxT("Shortcuts manager being created multiple times"));
   g_pShortcutsManager = new PWSMenuShortcuts(menubar);
   return g_pShortcutsManager;
 }
@@ -361,7 +357,7 @@ PWSMenuShortcuts* PWSMenuShortcuts::GetShortcutsManager()
 void PWSMenuShortcuts::DestroyShortcutsManager()
 {
   delete g_pShortcutsManager;
-  g_pShortcutsManager = 0;
+  g_pShortcutsManager = nullptr;
 }
 
 wxString PWSMenuShortcuts::MenuLabelAt(size_t index) const
@@ -384,7 +380,7 @@ wxAcceleratorEntry PWSMenuShortcuts::OriginalShortcutAt(size_t index) const
 
 wxMenuItem* PWSMenuShortcuts::MenuItemAt(size_t index) const
 {
-  wxCHECK_MSG(index < Count(), 0, wxT("Index for menuitem exceeds number of menu items retrieved"));
+  wxCHECK_MSG(index < Count(), nullptr, wxT("Index for menuitem exceeds number of menu items retrieved"));
   return m_midata[index].GetMenuItem();
 }
 
@@ -620,6 +616,7 @@ void PWSMenuShortcuts::OnShortcutKey(wxKeyEvent& evt)
 void PWSMenuShortcuts::OnKeyChar(wxKeyEvent& evt)
 {
   wxWindow* gridWindow = wxDynamicCast(evt.GetEventObject(), wxWindow);
+  wxCHECK_RET(gridWindow, wxT("Could not get gridWindow from wxKeyEvent"));
   wxGrid* grid = wxDynamicCast(gridWindow->GetParent(), wxGrid);
   wxCHECK_RET(grid, wxT("Could not get grid from wxKeyEvent"));
   wxASSERT_MSG(grid == m_shortcutsGrid, wxT("Events from unexpected grid"));
