@@ -15,10 +15,6 @@
 // For compilers that support precompilation, includes "wx/wx.h".
 #include "wx/wxprec.h"
 
-#ifdef __BORLANDC__
-#pragma hdrstop
-#endif
-
 #ifndef WX_PRECOMP
 #include "wx/wx.h"
 #endif
@@ -50,6 +46,7 @@
 #include "QRCodeDlg.h"
 #include "TimedTaskChain.h"
 #include "TreeCtrl.h"
+#include "ViewAttachmentDlg.h"
 #include "wxUtilities.h"
 
 #include <array>
@@ -57,28 +54,37 @@
 
 using pws_os::CUUID;
 
-//This function intentionally takes the argument by value and not by
-//reference to avoid touching an item invalidated by idle timeout
+/**
+ * This function intentionally takes the argument by value and not by
+ * reference to avoid touching an item invalidated by idle timeout.
+ */
 void PasswordSafeFrame::DoEdit(CItemData item)
 {
-  int rc = 0;
+  int returnCode = 0;
+
   if (!item.IsShortcut()) {
-    bool read_only = m_core.IsReadOnly() || item.IsProtected();
-    AddEditPropSheetDlg editDbox(this, m_core,
-                              read_only ? AddEditPropSheetDlg::SheetType::VIEW : AddEditPropSheetDlg::SheetType::EDIT,
-                              &item);
-    rc = editDbox.ShowModal();
-  } else {
-    EditShortcutDlg editDbox(this, m_core, &item);
-    rc = editDbox.ShowModal();
+    bool isItemReadOnly = m_core.IsReadOnly() || item.IsProtected();
+
+    AddEditPropSheetDlg dialog(
+      this, m_core,
+      isItemReadOnly ? AddEditPropSheetDlg::SheetType::VIEW : AddEditPropSheetDlg::SheetType::EDIT,
+      &item
+    );
+
+    returnCode = dialog.ShowModal();
   }
-  if (rc == wxID_OK) {
+  else {
+    EditShortcutDlg dialog(this, m_core, &item);
+    returnCode = dialog.ShowModal();
+  }
+
+  if (returnCode == wxID_OK) {
     uuid_array_t uuid;
     item.GetUUID(uuid);
     //Find the item in the database, which might have been loaded afresh
     //after lock/unlock, so the old data structures are no longer valid
-    auto iter = m_core.Find(uuid);
-    if ( iter != m_core.GetEntryEndIter()) {
+    const auto iter = m_core.Find(uuid);
+    if (iter != m_core.GetEntryEndIter()) {
       CItemData& origItem = m_core.GetEntry(iter);
       //The Item is updated in DB by AddEditPropSheetDlg
       UpdateAccessTime(origItem);
@@ -95,18 +101,17 @@ void PasswordSafeFrame::DoEdit(CItemData item)
  * wxEVT_COMMAND_MENU_SELECTED event handler for wxID_ADD
  */
 
-void PasswordSafeFrame::OnAddClick( wxCommandEvent& /* evt */ )
+void PasswordSafeFrame::OnAddClick(wxCommandEvent& WXUNUSED(evt))
 {
   wxString selectedGroup = wxEmptyString;
   wxTreeItemId selection;
+
   if (IsTreeView() && (selection = m_tree->GetSelection()).IsOk() && m_tree->ItemIsGroup(selection)) {
     selectedGroup = m_tree->GetItemGroup(selection);
   }
 
   AddEditPropSheetDlg addDbox(this, m_core, AddEditPropSheetDlg::SheetType::ADD, nullptr, selectedGroup);
   if (addDbox.ShowModal() == wxID_OK) {
-    const CItemData &item = addDbox.GetItem();
-    m_core.Execute(AddEntryCommand::Create(&m_core, item, item.GetBaseUUID()));
     UpdateStatusBar();
   }
 }
@@ -115,7 +120,7 @@ void PasswordSafeFrame::OnAddClick( wxCommandEvent& /* evt */ )
  * wxEVT_COMMAND_MENU_SELECTED event handler for ID_EDIT
  */
 
-void PasswordSafeFrame::OnEditClick( wxCommandEvent& /* evt */ )
+void PasswordSafeFrame::OnEditClick(wxCommandEvent& WXUNUSED(evt))
 {
   CItemData *item = GetSelectedEntry();
   if (item != nullptr)
@@ -126,7 +131,7 @@ void PasswordSafeFrame::OnEditClick( wxCommandEvent& /* evt */ )
  * wxEVT_COMMAND_MENU_SELECTED event handler for wxID_DELETE
  */
 
-void PasswordSafeFrame::OnDeleteClick( wxCommandEvent& /* evt */ )
+void PasswordSafeFrame::OnDeleteClick(wxCommandEvent& WXUNUSED(evt))
 {
   bool dontaskquestion = PWSprefs::GetInstance()->
     GetPref(PWSprefs::DeleteQuestion);
@@ -231,7 +236,7 @@ Command *PasswordSafeFrame::Delete(wxTreeItemId tid)
  * wxEVT_COMMAND_MENU_SELECTED event handler for wxID_FIND
  */
 
-void PasswordSafeFrame::OnFindClick( wxCommandEvent& /* evt */ )
+void PasswordSafeFrame::OnFindClick(wxCommandEvent& WXUNUSED(evt))
 {
   m_search->Activate();
 }
@@ -240,7 +245,7 @@ void PasswordSafeFrame::OnFindClick( wxCommandEvent& /* evt */ )
  * wxEVT_COMMAND_MENU_SELECTED event handler for wxID_EDITMENU_FIND_NEXT
  */
 
-void PasswordSafeFrame::OnFindNext( wxCommandEvent& /* evt */ )
+void PasswordSafeFrame::OnFindNext(wxCommandEvent& WXUNUSED(evt))
 {
   m_search->FindNext();
 }
@@ -249,7 +254,7 @@ void PasswordSafeFrame::OnFindNext( wxCommandEvent& /* evt */ )
  * wxEVT_COMMAND_MENU_SELECTED event handler for wxID_EDITMENU_FIND_PREVIOUS
  */
 
-void PasswordSafeFrame::OnFindPrevious( wxCommandEvent& /* evt */ )
+void PasswordSafeFrame::OnFindPrevious(wxCommandEvent& WXUNUSED(evt))
 {
   m_search->FindPrevious();
 }
@@ -339,7 +344,7 @@ void PasswordSafeFrame::OnDuplicateEntry(wxCommandEvent& WXUNUSED(event))
  * wxEVT_COMMAND_MENU_SELECTED event handler for ID_CLEARCLIPBOARD
  */
 
-void PasswordSafeFrame::OnClearClipboardClick( wxCommandEvent& /* evt */ )
+void PasswordSafeFrame::OnClearClipboardClick(wxCommandEvent& WXUNUSED(evt))
 {
   UpdateLastClipboardAction(CItemData::FieldType::END);
   Clipboard::GetInstance()->ClearCBData();
@@ -492,7 +497,57 @@ void PasswordSafeFrame::OnAutoType(wxCommandEvent& evt)
   }
 }
 
-void PasswordSafeFrame::OnGotoBase(wxCommandEvent& /*evt*/)
+void PasswordSafeFrame::OnViewAttachment(wxCommandEvent& WXUNUSED(evt))
+{
+  CItemData* item = GetSelectedEntry();
+
+  if (item == nullptr) {
+    return;
+  }
+
+  if (!item->HasAttRef()) {
+    return;
+  }
+
+  ASSERT(m_core.HasAtt(item->GetAttUUID()));
+
+  CItemAtt itemAttachment = m_core.GetAtt(item->GetAttUUID());
+
+  // Shouldn't be here if no content
+  if (!itemAttachment.HasContent()) {
+    return;
+  }
+
+  // Get media type before we find we can't load it
+  auto mediaTypeDescription = stringx2std(itemAttachment.GetMediaType());
+
+  if (!IsMimeTypeImage(mediaTypeDescription)) {
+    wxMessageDialog(
+      this,
+      _("There is no view available for attachments that are not of image media type.\n"),
+      _("View Attachment"),
+      wxICON_INFORMATION
+    ).ShowModal();
+
+    return;
+  }
+
+  ViewAttachmentDlg viewAttachmentDlg(this);
+
+  if (viewAttachmentDlg.LoadImage(itemAttachment)) {
+    viewAttachmentDlg.ShowModal();
+  }
+  else {
+    wxMessageDialog(
+      this,
+      _("No preview available due to an error."),
+      _("View Attachment"),
+      wxICON_ERROR
+    ).ShowModal();
+  }
+}
+
+void PasswordSafeFrame::OnGotoBase(wxCommandEvent& WXUNUSED(evt))
 {
   CItemData* item = GetSelectedEntry();
   if (item && (item->IsAlias() || item->IsShortcut())) {
@@ -618,7 +673,7 @@ void PasswordSafeFrame::MaybeRestoreUI(bool autotype_err, wxString autotype_err_
     }
   }
   if (autotype_err)
-    wxMessageBox(_("There was an error autotyping.  ") + autotype_err_msg, _T("Autotype error"), wxOK|wxICON_ERROR, this);
+    wxMessageBox(_("There was an error autotyping.  ") + autotype_err_msg, _("Autotype error"), wxOK|wxICON_ERROR, this);
 }
 
 /*
@@ -664,7 +719,7 @@ void PasswordSafeFrame::DoAutotype(const StringX& sx_autotype,
         case L'w':
         case L'W':
         {
-           if (std::find(vactionverboffsets.begin(), vactionverboffsets.end(), (size_t)(n - 1)) ==
+           if (std::find(vactionverboffsets.begin(), vactionverboffsets.end(), static_cast<size_t>(n - 1)) ==
                vactionverboffsets.end()) {
              // Not in the list of found action verbs - treat as-is
              sxtmp += L'\\';
@@ -710,7 +765,7 @@ void PasswordSafeFrame::DoAutotype(const StringX& sx_autotype,
           break; // case 'd', 'w' & 'W'
         }
         case L'c':
-          if (std::find(vactionverboffsets.begin(), vactionverboffsets.end(), (size_t)(n - 1)) ==
+          if (std::find(vactionverboffsets.begin(), vactionverboffsets.end(), static_cast<size_t>(n - 1)) ==
               vactionverboffsets.end()) {
             // Not in the list of found action verbs - treat as-is
             sxtmp += L'\\';
@@ -722,7 +777,7 @@ void PasswordSafeFrame::DoAutotype(const StringX& sx_autotype,
           break;
         case L'j':
         case L'k':
-          if (std::find(vactionverboffsets.begin(), vactionverboffsets.end(), (size_t)(n - 1)) ==
+          if (std::find(vactionverboffsets.begin(), vactionverboffsets.end(), static_cast<size_t>(n - 1)) ==
               vactionverboffsets.end()) {
             // Not in the list of found action verbs - treat as-is
             sxtmp += L'\\';
@@ -733,7 +788,7 @@ void PasswordSafeFrame::DoAutotype(const StringX& sx_autotype,
           }
           break;
         case L'z':
-          if (std::find(vactionverboffsets.begin(), vactionverboffsets.end(), (size_t)(n - 1)) ==
+          if (std::find(vactionverboffsets.begin(), vactionverboffsets.end(), static_cast<size_t>(n - 1)) ==
               vactionverboffsets.end()) {
             // Not in the list of found action verbs - treat as-is
             sxtmp += L'\\';
@@ -741,7 +796,7 @@ void PasswordSafeFrame::DoAutotype(const StringX& sx_autotype,
           }
           break;
         case L'b':
-          if (std::find(vactionverboffsets.begin(), vactionverboffsets.end(), (size_t)(n - 1)) ==
+          if (std::find(vactionverboffsets.begin(), vactionverboffsets.end(), static_cast<size_t>(n - 1)) ==
               vactionverboffsets.end()) {
             // Not in the list of found action verbs - treat as-is
             sxtmp += L'\\';
@@ -797,9 +852,9 @@ void PasswordSafeFrame::DoBrowse(CItemData &item, bool bAutotype)
   }
 }
 
-bool PasswordSafeFrame::LaunchBrowser(const wxString &csURL, const StringX &/*sxAutotype*/,
-                             const std::vector<size_t> &/*vactionverboffsets*/,
-                             bool /*bDoAutotype*/)
+bool PasswordSafeFrame::LaunchBrowser(const wxString &csURL, const StringX & WXUNUSED(sxAutotype),
+                             const std::vector<size_t> & WXUNUSED(vactionverboffsets),
+                             bool WXUNUSED(bDoAutotype))
 {
   /*
    * This is a straight port of DBoxMain::LaunchBrowser.  See the comments in that function
@@ -910,7 +965,7 @@ void PasswordSafeFrame::DoRun(CItemData& item)
 
   if (!errorMessage.empty()) {
     wxMessageBox(
-      wxString::Format(_("Error at column %d:\n\n%s"), (int)columnPosition, errorMessage.c_str()), 
+      wxString::Format(_("Error at column %d:\n\n%s"), static_cast<int>(columnPosition), errorMessage.c_str()), 
       _("Error parsing Run Command"), 
       wxOK|wxICON_ERROR, this);
 
