@@ -11,46 +11,18 @@
 */
 
 // For compilers that support precompilation, includes "wx/wx.h".
-#include "wx/wxprec.h"
-#include "wx/cmdline.h"
-
-#ifdef __BORLANDC__
-#pragma hdrstop
-#endif
+#include <wx/wxprec.h>
 
 #ifndef WX_PRECOMP
 #include "wx/wx.h"
 #endif
 
-////@begin includes
-////@end includes
-
-#include <iostream> // currently for debugging
-#include <clocale>  // to get the locales specified by the environment 
-                    // for used functions like wcstombs in src/os/file.h
-#include <functional>
-
-using namespace std;
-
-#include "PWSafeApp.h"
-#include "PasswordSafeFrame.h"
-#include "version.h"
-#include "wxMessages.h"
-#include "Clipboard.h"
-#include "GridShortcutsValidator.h"
-#include "CryptKeyEntryDlg.h"
-#if defined(__X__) || defined(__WXGTK__)
-#include "Clipboard.h"
+#ifdef __WXMSW__
+#include <wx/msw/msvcrt.h>
 #endif
 
-#include "os/cleanup.h"
-#include "os/dir.h"
-#include "core/PWSfile.h"
-#include "core/PWSLog.h"
-#include "core/PWSprefs.h"
-#include "core/PWSrand.h"
-#include "core/SysInfo.h"
-
+////@begin includes
+#include <wx/cmdline.h>
 #include <wx/fs_arc.h>
 #include <wx/html/helpctrl.h>
 #include <wx/propdlg.h>
@@ -61,17 +33,42 @@ using namespace std;
 #include <wx/tokenzr.h>
 #include <wx/spinctrl.h>
 
-#ifdef __WXMSW__
-#include <wx/msw/msvcrt.h>
-#endif
 #if wxCHECK_VERSION(2,9,2)
 #include <wx/richmsgdlg.h>
 #endif
-////@begin XPM images
-#include "./graphics/pwsafe16.xpm"
-#include "./graphics/pwsafe32.xpm"
-#include "./graphics/pwsafe48.xpm"
+////@end includes
 
+#include "os/cleanup.h"
+#include "os/dir.h"
+#include "core/PWSfile.h"
+#include "core/PWSLog.h"
+#include "core/PWSprefs.h"
+#include "core/PWSrand.h"
+#include "core/SysInfo.h"
+#include "wxUtilities.h"
+
+#if defined(__X__) || defined(__WXGTK__) || defined(__WXOSX__)
+#include "Clipboard.h"
+#endif
+#include "CryptKeyEntryDlg.h"
+#include "GridShortcutsValidator.h"
+#include "PasswordSafeFrame.h"
+#include "PWSafeApp.h"
+#include "version.h"
+#include "wxMessages.h"
+#include "Clipboard.h"
+
+#include <iostream> // currently for debugging
+#include <clocale>  // to get the locales specified by the environment 
+                    // for used functions like wcstombs in src/os/file.h
+#include <functional>
+
+using namespace std;
+
+////@begin XPM images
+#include "graphics/pwsafe16.xpm"
+#include "graphics/pwsafe32.xpm"
+#include "graphics/pwsafe48.xpm"
 ////@end XPM images
 
 #if wxCHECK_VERSION(2,9,0)
@@ -140,7 +137,7 @@ static const wxCmdLineEntryDesc cmdLineDesc[] = {
 static wxReporter aReporter;
 static wxAsker    anAsker;
 
-static void cleanup_handler(int /*signum */, void *p)
+static void cleanup_handler(int WXUNUSED(signum), void *p)
 {
   // Called if we get a signal - don't try to save, since we don't
   // know what's valid, if anything. Just unlock file, if any.
@@ -180,7 +177,7 @@ IMPLEMENT_CLASS( PWSafeApp, wxApp )
  */
 
 PWSafeApp::PWSafeApp() : m_idleTimer(new wxTimer(this, IDLE_TIMER_ID)),
-                         m_frame(0), m_recentDatabases(0),
+                         m_frame(nullptr), m_recentDatabases(nullptr),
                          m_locale(nullptr)
 {
   Init();
@@ -275,7 +272,7 @@ bool PWSafeApp::OnInit()
   // For instance, the behavior of function 'wcstombs' depends on the LC_CTYPE 
   // category of the selected C locale.
   setlocale(LC_CTYPE, "");
-  
+
   //Used by help subsystem
   wxFileSystem::AddHandler(new wxArchiveFSHandler);
 
@@ -346,7 +343,7 @@ bool PWSafeApp::OnInit()
       CryptKeyEntryDlg dialog(mode);
 
       if (dialog.ShowModal() == wxID_OK) {
-        if (!func(filename.wc_str(), dialog.getCryptKey(), errstr)) {
+        if (!func(tostdstring(filename), dialog.getCryptKey(), errstr)) {
           wxMessageDialog messageBox(
             nullptr, errstr, _("Error"), wxOK | wxICON_ERROR
           );
