@@ -22,7 +22,6 @@
 #include <wx/msw/msvcrt.h>
 #endif
 
-#include "core/PwsPlatform.h"
 #include "core/PWHistory.h"
 #include "core/Util.h"
 #include "wxUtilities.h"
@@ -72,7 +71,7 @@ enum {
   ID_FIND_STATUS_AREA
 }; // see also PasswordSafeSearch::CalculateToolsWidth() in case of updates
 
-PasswordSafeSearch::PasswordSafeSearch(PasswordSafeFrame* parent) : m_toolbar(0),
+PasswordSafeSearch::PasswordSafeSearch(PasswordSafeFrame* parent) : m_toolbar(nullptr),
                                                                     m_parentFrame(parent),
                                                                     m_criteria(new SelectionCriteria)
 {
@@ -81,10 +80,10 @@ PasswordSafeSearch::PasswordSafeSearch(PasswordSafeFrame* parent) : m_toolbar(0)
 PasswordSafeSearch::~PasswordSafeSearch()
 {
   delete m_toolbar;
-  m_toolbar = 0;
+  m_toolbar = nullptr;
 
   delete m_criteria;
-  m_criteria = 0;
+  m_criteria = nullptr;
 }
 
 void PasswordSafeSearch::OnSearchTextChanged(wxCommandEvent& event)
@@ -118,7 +117,7 @@ void PasswordSafeSearch::OnDoSearchT(Iter begin, Iter end, Accessor afn)
   wxASSERT(m_toolbar);
 
   wxSearchCtrl* txtCtrl = wxDynamicCast(m_toolbar->FindControl(ID_FIND_EDITBOX), wxSearchCtrl);
-  wxASSERT(txtCtrl);
+  wxCHECK_RET(txtCtrl, wxT("Could not get search control of toolbar"));
 
   const wxString searchText = txtCtrl->GetLineText(0);
 
@@ -151,6 +150,10 @@ void PasswordSafeSearch::OnDoSearchT(Iter begin, Iter end, Accessor afn)
     m_criteria->Clean();
     txtCtrl->SetModified(false);
     m_searchPointer.InitIndex();
+
+    // Set last find filter
+    UUIDVector res(m_searchPointer);
+    m_parentFrame->SetFilterFindEntries(&res);
   }
   else {
     ++m_searchPointer;
@@ -159,7 +162,7 @@ void PasswordSafeSearch::OnDoSearchT(Iter begin, Iter end, Accessor afn)
   UpdateView();
 
   // Replace the "Find" menu item under Edit menu by "Find Next" and "Find Previous"
-  wxMenu* editMenu = 0;
+  wxMenu* editMenu = nullptr;
   wxMenuItem* findItem = m_parentFrame->GetMenuBar()->FindItem(wxID_FIND, &editMenu);
   if (findItem && editMenu) {
     //Is there a way to do this without hard-coding the insert position?
@@ -215,6 +218,7 @@ void PasswordSafeSearch::OnSearchClear(wxCommandEvent& WXUNUSED(event))
   txtCtrl->Clear();
   m_searchPointer.Clear();
   ClearToolbarStatusArea();
+  m_parentFrame->SetFilterFindEntries(nullptr);
 }
 
 /**
@@ -239,7 +243,7 @@ void PasswordSafeSearch::UpdateStatusAreaWidth()
   auto control = m_toolbar->FindControl(ID_FIND_STATUS_AREA);
 
   if (control) {
-    auto statusAreaWidth = (m_toolbar->GetParent()->GetClientSize()).GetWidth() - m_ToolsWidth;
+    int statusAreaWidth = (m_toolbar->GetParent()->GetClientSize()).GetWidth() - static_cast<int>(m_ToolsWidth);
 
     if (statusAreaWidth < 0) {
       return;
@@ -295,7 +299,8 @@ void PasswordSafeSearch::CalculateToolsWidth()
 wxSize PasswordSafeSearch::CalculateSearchWidth()
 {
   auto width = m_parentFrame->GetSize().GetWidth() < 570 ? (m_parentFrame->GetSize().GetWidth() / 3) : 200;
-  return wxSize(width, wxDefaultSize.GetHeight());
+
+  return wxSize(width, 30);
 }
 
 void PasswordSafeSearch::HideSearchToolbar()
@@ -308,13 +313,13 @@ void PasswordSafeSearch::HideSearchToolbar()
   m_parentFrame->GetSizer()->Layout();
   m_parentFrame->SetFocus();
 
-  wxMenu* editMenu = 0; // will be set by FindItem() below
+  wxMenu* editMenu = nullptr; // will be set by FindItem() below
   wxMenuItem* findNextItem = m_parentFrame->GetMenuBar()->FindItem(ID_EDITMENU_FIND_NEXT, &editMenu);
   if (editMenu) {       // the menu might not have been modified if nothing was actually searched for
     if (findNextItem) {
       editMenu->Delete(findNextItem);
     }
-    wxMenuItem* findPreviousItem = m_parentFrame->GetMenuBar()->FindItem(ID_EDITMENU_FIND_PREVIOUS, 0);
+    wxMenuItem* findPreviousItem = m_parentFrame->GetMenuBar()->FindItem(ID_EDITMENU_FIND_PREVIOUS, nullptr);
     if (findPreviousItem) {
       editMenu->Delete(findPreviousItem);
     }
@@ -333,11 +338,11 @@ struct FindDlgType {
     return _("Advanced Find Options");
   }
 
-  static bool IsMandatoryField(CItemData::FieldType /*field*/) {
+  static bool IsMandatoryField(CItemData::FieldType WXUNUSED(field)) {
     return false;
   }
 
-  static bool IsPreselectedField(CItemData::FieldType /*field*/) {
+  static bool IsPreselectedField(CItemData::FieldType WXUNUSED(field)) {
     return true;
   }
 
