@@ -13,25 +13,23 @@
 // For compilers that support precompilation, includes "wx/wx.h".
 #include "wx/wxprec.h"
 
-#ifdef __BORLANDC__
-#pragma hdrstop
-#endif
-
 #ifndef WX_PRECOMP
 #include "wx/wx.h"
 #endif
 
+#ifdef __WXMSW__
+#include <wx/msw/msvcrt.h>
+#endif
+
 ////@begin includes
 #include <wx/grid.h>
 #include <wx/textdlg.h>
 ////@end includes
 
-#include <vector>
 #include "PropertiesDlg.h"
+#include "wxUtilities.h"
 
-#ifdef __WXMSW__
-#include <wx/msw/msvcrt.h>
-#endif
+#include <vector>
 
 ////@begin XPM images
 ////@end XPM images
@@ -283,7 +281,7 @@ void PropertiesDlg::CreateControls()
 
   auto flexGridSizer = new wxFlexGridSizer(3 /*cols*/, 0 /*vgap*/, 0 /*hgap*/);
   flexGridSizer->AddGrowableCol(1);
-  mainSizer->Add(flexGridSizer, 1, /*wxALIGN_CENTER_HORIZONTAL|*/wxALL|wxEXPAND, 5);
+  mainSizer->Add(flexGridSizer, 1, wxALL|wxEXPAND, 5);
 
   auto itemStaticText6 = new wxStaticText( this, wxID_STATIC, _("Database format:"), wxDefaultPosition, wxDefaultSize, 0 );
   auto dbFormatText = new wxStaticText( this, wxID_DATABASEFORMAT, wxT("9.99"), wxDefaultPosition, wxDefaultSize, 0 );
@@ -461,7 +459,7 @@ void PropertiesDlg::OnEditName( wxCommandEvent& WXUNUSED(evt) )
     }
 
     if (Validate() && TransferDataToWindow()) {
-      m_NewDbName = std2stringx(newDbName.wc_str());
+      m_NewDbName = tostringx(newDbName);
     }
   }
 }
@@ -489,7 +487,7 @@ void PropertiesDlg::OnEditDescription( wxCommandEvent& WXUNUSED(evt) )
     }
 
     if (Validate() && TransferDataToWindow()) {
-      m_NewDbDescription = std2stringx(newDbDescription.wc_str());
+      m_NewDbDescription = tostringx(newDbDescription);
     }
   }
 }
