@@ -11,35 +11,33 @@
 */
 
 // For compilers that support precompilation, includes "wx/wx.h".
-#include "wx/wxprec.h"
-
-#ifdef __BORLANDC__
-#pragma hdrstop
-#endif
+#include <wx/wxprec.h>
 
 #ifndef WX_PRECOMP
-#include "wx/wx.h"
+#include <wx/wx.h>
 #endif
 
-#include "./SyncWizard.h"
-#include "./OpenFilePickerValidator.h"
-#include "./SafeCombinationCtrl.h"
-#include "./DbSelectionPanel.h"
-#include "./AdvancedSelectionDlg.h"
-#include "../../core/PWScore.h"
-#include "./SelectionCriteria.h"
+#ifdef __WXMSW__
+#include <wx/msw/msvcrt.h>
+#endif
 
 #include <wx/filename.h>
 #include <wx/valgen.h>
 #include <wx/statline.h>
 #include <wx/collpane.h>
+
+#include "core/PWScore.h"
+
+#include "AdvancedSelectionDlg.h"
+#include "DbSelectionPanel.h"
+#include "OpenFilePickerValidator.h"
+#include "SafeCombinationCtrl.h"
+#include "SelectionCriteria.h"
+#include "SyncWizard.h"
+
 #include <algorithm>
 #include <iterator>
 
-#ifdef __WXMSW__
-#include <wx/msw/msvcrt.h>
-#endif
-
 /*!
  * SyncData class declaration
  *
@@ -75,9 +73,9 @@ public:
   void OnWizardPageChanging(wxWizardEvent& evt);
   void OnWizardPageChanged(wxWizardEvent& evt);
 
-  virtual void OnPageEnter(PageDirection /*direction*/) {}
+  virtual void OnPageEnter(PageDirection WXUNUSED(direction)) {}
   //return false to veto the page change
-  virtual bool OnPageLeave(PageDirection /*direction*/) { return true; }
+  virtual bool OnPageLeave(PageDirection WXUNUSED(direction)) { return true; }
 
   void SetChildWindowText(unsigned id, const wxString& str);
 
@@ -95,7 +93,7 @@ class SyncStartPage : public SyncWizardPage
 public:
   SyncStartPage(wxWizard* parent, SyncData* data);
 
-  virtual void SaveData(SyncData* /*data*/) {}
+  virtual void SaveData(SyncData* WXUNUSED(data)) {}
 };
 
 /*!
@@ -119,11 +117,11 @@ public:
 
 //helper class used by field selection page to construct the UI
 struct SyncFieldSelection {
-  static bool IsMandatoryField(CItemData::FieldType /*field*/) {
+  static bool IsMandatoryField(CItemData::FieldType WXUNUSED(field)) {
     return false;
   }
 
-  static bool IsPreselectedField(CItemData::FieldType /*field*/) {
+  static bool IsPreselectedField(CItemData::FieldType WXUNUSED(field)) {
     return true;
   }
 
@@ -181,7 +179,7 @@ public:
   SyncOptionsSummaryPage(wxWizard* parent, SyncData* data);
 
   virtual void OnPageEnter(PageDirection dir);
-  virtual void SaveData(SyncData* /*data*/) {}
+  virtual void SaveData(SyncData* WXUNUSED(data)) {}
 };
 
 /*!
@@ -207,7 +205,7 @@ class SyncStatusPage: public SyncWizardPage
 public:
   SyncStatusPage(wxWizard* parent, SyncData* data);
 
-  virtual void SaveData(SyncData* /*data*/) {}
+  virtual void SaveData(SyncData* WXUNUSED(data)) {}
   virtual void OnPageEnter(PageDirection dir);
 };
 
@@ -220,7 +218,7 @@ END_EVENT_TABLE()
 
 SyncWizard::SyncWizard(wxWindow* parent, PWScore* core):
                 wxWizard(parent, wxID_ANY, _("Synchronize another database with currently open database")),
-                m_page1(0), m_syncData(new SyncData)
+                m_page1(nullptr), m_syncData(new SyncData)
 {
   //select all fields, except those below
   m_syncData->selCriteria.SelectAllFields();
@@ -261,7 +259,7 @@ SyncWizard::SyncWizard(wxWindow* parent, PWScore* core):
 SyncWizard::~SyncWizard()
 {
   delete m_syncData;
-  m_syncData = 0;
+  m_syncData = nullptr;
 }
 
 void SyncWizard::OnWizardPageChanging(wxWizardEvent& evt)
@@ -321,7 +319,7 @@ void SyncWizardPage::OnWizardPageChanging(wxWizardEvent& evt)
   SyncWizardPage* page = wxDynamicCast(evt.GetPage(), SyncWizardPage);
   wxASSERT_MSG(page, wxT("Sync wizard page not derived from SyncWizardPage class"));
 
-  if (!page->OnPageLeave(evt.GetDirection() ? PageDirection::FORWARD : PageDirection::BACKWARD))
+  if (page && !page->OnPageLeave(evt.GetDirection() ? PageDirection::FORWARD : PageDirection::BACKWARD))
     evt.Veto();
 
   //must always do this, to let the wizard see the event as well
@@ -332,8 +330,9 @@ void SyncWizardPage::OnWizardPageChanged(wxWizardEvent& evt)
 {
   SyncWizardPage* page = wxDynamicCast(evt.GetPage(), SyncWizardPage);
   wxASSERT_MSG(page, wxT("Sync wizard page not derived from SyncWizardPage class"));
-
-  page->OnPageEnter(evt.GetDirection() ? PageDirection::FORWARD : PageDirection::BACKWARD);
+  if (page) {
+    page->OnPageEnter(evt.GetDirection() ? PageDirection::FORWARD : PageDirection::BACKWARD);
+  }
 
   //must always do this, to let the wizard see the event as well
   evt.Skip();
@@ -428,8 +427,8 @@ void SyncFieldSelectionPage::SaveData(SyncData* data)
 //
 SyncOptionsSummaryPage::SyncOptionsSummaryPage(wxWizard* parent, SyncData* data)
                               : SyncWizardPage(parent, data, _("Options Summary")),
-                                m_updatedFieldsGrid(0),
-                                m_notUpdatedFieldsGrid(0)
+                                m_updatedFieldsGrid(nullptr),
+                                m_notUpdatedFieldsGrid(nullptr)
 {
   wxSizerFlags flags = wxSizerFlags().Expand().Proportion(0).Border(wxLEFT+wxRIGHT, SideMargin);
   wxSizerFlags gridFlags = wxSizerFlags().Expand().Proportion(1).Border(wxLEFT+wxRIGHT, SideMargin*2);
@@ -455,7 +454,7 @@ SyncOptionsSummaryPage::SyncOptionsSummaryPage(wxWizard* parent, SyncData* data)
   const wxString warning(_("WARNING!!\n\nIf you continue, fields will be updated in your existing database\nfrom your selected input database"));
   wxStaticText* txtWarn = new wxStaticText(this, wxID_ANY, warning);
   txtWarn->SetForegroundColour(*wxRED);
-  sizer->Add(txtWarn, flags.Proportion(0).Bottom());
+  sizer->Add(txtWarn, flags.Proportion(0));
 
   SetSizerAndFit(sizer);
 }
@@ -508,7 +507,7 @@ DEFINE_EVENT_TYPE(wxEVT_SYNC_START)
 SyncStatusPage::SyncStatusPage(wxWizard* parent, SyncData* data): SyncWizardPage(parent, data, _("Synchronization status"))
 {
   wxBoxSizer* sizer = m_pageSizer;
-  wxSizerFlags flags = wxSizerFlags().Expand().Proportion(1).Border(wxLEFT|wxRIGHT, SideMargin).Align(wxALIGN_CENTER_VERTICAL);
+  wxSizerFlags flags = wxSizerFlags().Expand().Proportion(1).Border(wxLEFT|wxRIGHT, SideMargin);
 
   sizer->Add(new wxStaticText(this, ID_HEADER_TXT, wxEmptyString), flags.Proportion(1));
   sizer->AddSpacer(RowSeparation);
@@ -525,7 +524,7 @@ SyncStatusPage::SyncStatusPage(wxWizard* parent, SyncData* data): SyncWizardPage
   horizSizer->Add(new wxStaticText(this, ID_FINISH_TXT, wxEmptyString), wxSizerFlags().Expand().Proportion(1));
   horizSizer->Add(new wxCheckBox(this, ID_SHOW_REPORT, _("See a detailed report"), wxDefaultPosition,
                       wxDefaultSize, 0, wxGenericValidator(&m_syncData->showReport)),
-                    wxSizerFlags().Proportion(0).Right());
+                    wxSizerFlags().Proportion(0));
   sizer->Add(horizSizer, flags.Proportion(1));
 
   SetSizerAndFit(sizer);
@@ -584,7 +583,7 @@ void SyncStatusPage::OnSyncStartEvent(wxCommandEvent& evt)
   Synchronize(m_syncData->core, otherCore);
 
   SetHeaderText(wxString::Format(_("Your database has been synchronized with \"%ls\""), otherCore->GetCurFile().c_str()));
-  SetProgressText(wxString::Format(_("%d %ls updated"), m_syncData->numUpdated,
+  SetProgressText(wxString::Format(_("%ld %ls updated"), m_syncData->numUpdated,
                       m_syncData->numUpdated == 1? _("entry"): _("entries")));
   SetSyncSummary(_("Synchronization completed successfully"));
 
@@ -695,13 +694,13 @@ void SyncStatusPage::Synchronize(PWScore* currentCore, const PWScore *otherCore)
       uuid_array_t current_uuid, other_uuid;
       curItem.GetUUID(current_uuid);
       otherItem.GetUUID(other_uuid);
-      if (memcmp((void *)current_uuid, (void *)other_uuid, sizeof(uuid_array_t)) != 0) {
+      if (memcmp(static_cast<void *>(current_uuid), static_cast<void *>(other_uuid), sizeof(uuid_array_t)) != 0) {
         pws_os::Trace(wxT("Synchronize: Mis-match UUIDs for [%ls:%ls:%ls]\n"), otherGroup.c_str(), otherTitle.c_str(), otherUser.c_str());
       }
 
       bool bUpdated(false);
-      for (int i = 0; i < (int)criteria.TotalFieldsCount(); i++) {
-        auto ft = (CItemData::FieldType)i;
+      for (size_t i = 0; i < criteria.TotalFieldsCount(); i++) {
+        auto ft = static_cast<CItemData::FieldType>(i);
         if (criteria.IsFieldSelected(ft)) {
           const StringX sxValue = otherItem.GetFieldValue(ft);
           if (sxValue != updItem.GetFieldValue(ft)) {
