@@ -13,10 +13,6 @@
 // For compilers that support precompilation, includes "wx/wx.h".
 #include <wx/wxprec.h>
 
-#ifdef __BORLANDC__
-#pragma hdrstop
-#endif
-
 #ifndef WX_PRECOMP
 #include <wx/wx.h>
 #endif
@@ -42,18 +38,18 @@
 
 ////@begin XPM images
 ////@end XPM images
-#include "./graphics/abase_exp.xpm"
-#include "./graphics/abase_warn.xpm"
-#include "./graphics/abase.xpm"
-#include "./graphics/alias.xpm"
-#include "./graphics/node.xpm"
-#include "./graphics/normal_exp.xpm"
-#include "./graphics/normal_warn.xpm"
-#include "./graphics/normal.xpm"
-#include "./graphics/sbase_exp.xpm"
-#include "./graphics/sbase_warn.xpm"
-#include "./graphics/sbase.xpm"
-#include "./graphics/shortcut.xpm"
+#include "graphics/abase_exp.xpm"
+#include "graphics/abase_warn.xpm"
+#include "graphics/abase.xpm"
+#include "graphics/alias.xpm"
+#include "graphics/node.xpm"
+#include "graphics/normal_exp.xpm"
+#include "graphics/normal_warn.xpm"
+#include "graphics/normal.xpm"
+#include "graphics/sbase_exp.xpm"
+#include "graphics/sbase_warn.xpm"
+#include "graphics/sbase.xpm"
+#include "graphics/shortcut.xpm"
 
 using pws_os::CUUID;
 
@@ -270,6 +266,7 @@ void TreeCtrl::UpdateGUI(UpdateGUICommand::GUI_Action ga, const pws_os::CUUID &e
       break;
     case UpdateGUICommand::GUI_DELETE_ENTRY:
       Remove(entry_uuid);
+      AddRootItem();
       break;
     case UpdateGUICommand::GUI_REFRESH_ENTRYFIELD:
     case UpdateGUICommand::GUI_REFRESH_ENTRYPASSWORD:
@@ -286,6 +283,9 @@ void TreeCtrl::UpdateGUI(UpdateGUICommand::GUI_Action ga, const pws_os::CUUID &e
       // Handled by PasswordSafeFrame
       break;
     case UpdateGUICommand::GUI_REFRESH_ENTRY:
+      ASSERT(item != nullptr);
+      UpdateItem(*item);
+      break;
     case UpdateGUICommand::GUI_REFRESH_GROUPS:
     case UpdateGUICommand::GUI_REFRESH_BOTHVIEWS:
       // TODO: ???
@@ -322,19 +322,47 @@ void TreeCtrl::GUIRefreshEntry(const CItemData &item, bool WXUNUSED(bAllowFail))
 
 /**
  * Provides the information wether a group tree item is selected.
- * It considers the root item as a group via 'ItemIsGroup'.
+ * It considers the root item as no group via 'ItemIsGroup'.
  */
 bool TreeCtrl::IsGroupSelected() const
 {
   return GetSelection().IsOk() && ItemIsGroup(GetSelection());
 }
 
-bool TreeCtrl::IsRootSelected() const
+/**
+ * Provides the indication whether any editable items exists in
+ * the tree view. Editable items are items from the database,
+ * hence the tree's root item is excluded.
+ */
+bool TreeCtrl::HasItems() const
 {
-  return GetSelection().IsOk() && GetSelection() == GetRootItem();
+  return (GetCount() > 0);
 }
 
+/**
+ * Provides the indication whether any in the tree visible item
+ * is selected. This excludes the tree's root item.
+ */
+bool TreeCtrl::HasSelection() const
+{
+  return GetSelection().IsOk() && (GetSelection() != GetRootItem());
+}
+
+/**
+ * Provides the information whether a tree item is a group.
+ * The tree's root item, as a not editable element, is considered
+ * as no group.
+ */
 bool TreeCtrl::ItemIsGroup(const wxTreeItemId& item) const
+{
+  int image = GetItemImage(item);
+  return image == NODE_II && GetRootItem() != item;
+}
+
+/**
+ * Provides the information whether a tree item is a group or root.
+ */
+bool TreeCtrl::ItemIsGroupOrRoot(const wxTreeItemId& item) const
 {
   int image = GetItemImage(item);
   return image == NODE_II || GetRootItem() == item;
@@ -505,7 +533,9 @@ void TreeCtrl::UpdateItem(const CItemData &item)
   }
 }
 
-//Just update the item's text, don't move it into its sorted position
+/**
+ * Just update the item's text, don't move it into its sorted position.
+ */
 void TreeCtrl::UpdateItemField(const CItemData &item, CItemData::FieldType ft)
 {
   PWSprefs* prefs = PWSprefs::GetInstance();
@@ -537,6 +567,27 @@ void TreeCtrl::AddItem(const CItemData &item)
   m_item_map.insert(std::make_pair(CUUID(uuid), titem));
 }
 
+/**
+ * Adds the root element to the tree if there is none.
+ *
+ * @note At least one tree element is needed to make the context menu work,
+ * otherwise it won't show. TreeCtrl::AddGroup checks if a root item is
+ * needed or an existing one is available.
+ */
+void TreeCtrl::AddRootItem()
+{
+  if (IsEmpty()) {
+    AddRoot(wxEmptyString);
+  }
+}
+
+void TreeCtrl::Clear()
+{
+  DeleteAllItems();
+  AddRootItem();
+  m_item_map.clear();
+}
+
 CItemData *TreeCtrl::GetItem(const wxTreeItemId &id) const
 {
   if (!id.IsOk())
@@ -553,7 +604,6 @@ CItemData *TreeCtrl::GetItem(const wxTreeItemId &id) const
   return &itemiter->second;
 }
 
-//overridden from base for case-insensitive sort
 int TreeCtrl::OnCompareItems(const wxTreeItemId& item1, const wxTreeItemId& item2)
 {
   const bool groupsFirst = PWSprefs::GetInstance()->GetPref(PWSprefs::ExplorerTypeTree),
@@ -574,7 +624,7 @@ int TreeCtrl::OnCompareItems(const wxTreeItemId& item1, const wxTreeItemId& item
 
 void TreeCtrl::SortChildrenRecursively(const wxTreeItemId& item)
 {
-  if (!ItemIsGroup(item) || GetChildrenCount(item) <= 0)
+  if (!ItemIsGroupOrRoot(item) || GetChildrenCount(item) <= 0)
     return;
 
   SortChildren(item);
@@ -685,15 +735,6 @@ void TreeCtrl::OnTreectrlItemActivated( wxTreeEvent& evt )
   }
 }
 
-/*!
- * wxEVT_TREE_ITEM_MENU event handler for ID_TREECTRL
- */
-
-void TreeCtrl::OnContextMenu( wxTreeEvent& evt )
-{
-  dynamic_cast<PasswordSafeFrame*>(GetParent())->OnContextMenu(GetItem(evt.GetItem()));
-}
-
 void TreeCtrl::SelectItem(const CUUID & uuid)
 {
   uuid_array_t uuid_array;
@@ -732,6 +773,7 @@ void EditTreeLabel(wxTreeCtrl* tree, const wxTreeItemId& id)
     edit->SelectAll();
   }
 }
+
 void TreeCtrl::OnAddGroup(wxCommandEvent& WXUNUSED(evt))
 {
   wxCHECK_RET(IsShown(), wxT("Group can only be added while in tree view"));
@@ -819,24 +861,34 @@ void TreeCtrl::OnKeyDown(wxTreeEvent& evt)
   evt.Skip();
 }
 
+/*!
+ * wxEVT_TREE_ITEM_MENU event handler for ID_TREECTRL
+ */
+
+void TreeCtrl::OnContextMenu( wxTreeEvent& evt )
+{
+  dynamic_cast<PasswordSafeFrame*>(GetParent())->OnContextMenu(GetItem(evt.GetItem()));
+}
+
+#if wxCHECK_VERSION(3, 1, 1)
+void TreeCtrl::OnContextMenu(wxContextMenuEvent& event)
+#else
 void TreeCtrl::OnMouseRightClick(wxMouseEvent& event)
+#endif // wxCHECK_VERSION(3, 1, 1)
 {
   wxPoint mouseClickPosition = event.GetPosition();
   int positionInfo;
 
+#if wxCHECK_VERSION(3, 1, 1)
+  HitTest(wxWindow::ScreenToClient(mouseClickPosition), positionInfo);
+#else
   HitTest(mouseClickPosition, positionInfo);
+#endif // wxCHECK_VERSION(3, 1, 1)
 
   if ((positionInfo & wxTREE_HITTEST_NOWHERE) == wxTREE_HITTEST_NOWHERE) {
     auto *parentWindow = dynamic_cast<PasswordSafeFrame*>(GetParent());
     wxASSERT(parentWindow != nullptr);
-    /*
-      Triggers an event that interferes with the popup menu in that sense that 
-      an invalid wxTreeItemId is provided at the moment when the popup menu shows.
-      This causes the menu items to get disabled at PasswordFrame::OnUpdateUI.
-      'Yield' solves this problem so that events are handled in the right order.
-    */
     Unselect();
-    wxGetApp().SafeYieldFor(parentWindow, wxEVT_CATEGORY_USER_INPUT);
     parentWindow->OnContextMenu(nullptr);
   }
   else {
@@ -915,11 +967,11 @@ void TreeCtrl::FinishRenamingGroup(wxTreeEvent& evt, wxTreeItemId groupItem, con
   typedef std::vector<StringX> EmptyGroupsArray;
   const EmptyGroupsArray& emptyGroups = m_core.GetEmptyGroups();
   StringX sxOldPathWithDot = sxOldPath + _T('.');
-  for( EmptyGroupsArray::const_iterator itr = emptyGroups.begin(); itr != emptyGroups.end(); ++itr)
+  for(const auto & emptyGroup : emptyGroups)
   {
-    if (*itr == sxOldPath || itr->find(sxOldPathWithDot) == 0) {
-      StringX sxOld = *itr;
-      StringX sxNew = sxNewPath + itr->substr(sxOldPath.size());
+    if (emptyGroup == sxOldPath || emptyGroup.find(sxOldPathWithDot) == 0) {
+      StringX sxOld = emptyGroup;
+      StringX sxNew = sxNewPath + emptyGroup.substr(sxOldPath.size());
       pmcmd->Add(DBEmptyGroupsCommand::Create(&m_core, sxOld, sxNew, DBEmptyGroupsCommand::EG_RENAME));
     }
   }
